-- -------------------------------------------------------------------------- --
-- CataCurrencyCalculator by kunda                                            --
-- -------------------------------------------------------------------------- --
-- GUI: Interface Options, LDB, Minimap or '/ccc'                             --
-- -------------------------------------------------------------------------- --

-- ------------------------------------------------------------------------------------------------------------------ --
--                                                                                                                    --
-- Source: Vaneras - http://forums.wow-europe.com/thread.html?topicId=14574620792&sid=1&pageNo=3#43                   --
--                                                                                                                    --
-- Here's some information on how each of the currencies will be converted in the next content patch. Keep in mind    --
-- these values may change, and they can get a bit math heavy. Just know that our intent is to appropriately value    --
-- each mark and provide a conversion we feel is fair.                                                                --
--                                                                                                                    --
-- The following items are immediately converted to gold:                                                             --
--                                                                                                                    --
--     Emblem of Heroism = 5.5 gold each                                                                              --
--     Emblem of Valor = 5.5 gold each                                                                                --
--     Emblem of Conquest = 5.5 gold each                                                                             --
--     Badge of Justice = 1.833 gold each                                                                             --
--                                                                                                                    --
--                                                                                                                    --
-- Your New Honor Points total will be the sum of the following amounts:                                              --
--                                                                                                                    --
--     Old Honor * 0.024                                                                                              --
--     Old Arena Points * 0.85                                                                                        --
--     Battleground Mark of Honor * 2.976                                                                             --
--     Wintergrasp Mark of Honor * 19.08                                                                              --
--     Stone Keeper Shard * 1.6                                                                                       --
--     Venture Coin * 3                                                                                               --
--     Spirit Shard * 1                                                                                               --
--                                                                                                                    --
--                                                                                                                    --
-- Your Justice Points total will be equal to (Emblems of Triumph + Emblems of Frost ) * 2.75                         --
--                                                                                                                    --
-- Again, the softcap for both Honor and Justice conversions is 4000 points. This means that if a character converts  --
-- to above 4,000 points, it will not be possible for them to earn more until they fall below the 4,000 cap.          --
--                                                                                                                    --
-- A hardcap will be implemented in a following patch before Cataclysm's release. At that time, any excess points     --
-- above 4,000 will be converted as follows:                                                                          --
--                                                                                                                    --
--     Honor points above 4,000 are converted to gold at a rate of 35 silver per point of Honor.                      --
--     Justice points above 4,000 are converted to gold at a rate of 2 gold per point of Justice.                     --
--                                                                                                                    --
-- ------------------------------------------------------------------------------------------------------------------ --

-- ---------------------------------------------------------------------------------------------------------------------
CataCurrencyCalculator_Options = {}
CataCurrencyCalculator = CreateFrame("Frame")

local L = CataCurrencyCalculator_Locales
local addonicon = "Interface\\MoneyFrame\\UI-GoldIcon"

local mult2 = 10^(2 or 0)
local _G = _G
local math_floor = _G.math.floor

-- Emblems and Badges ----------------------------------------------------------
local JusticeCap = 4000
local JusticeCapGold = 20000 -- 2 gold = 20000 copper
local EmblemsList = {
[29434] = {index=1, val=1.833}, -- Badges of Justice
[40752] = {index=2, val=5.5},   -- Emblems of Heroism
[40753] = {index=3, val=5.5},   -- Emblems of Valor
[45624] = {index=4, val=5.5},   -- Emblems of Conquest
[47241] = {index=5, val=2.75},  -- Emblems of Triumph - Justice Points = (Emblems of Triumph + Emblems of Frost ) * 2.75
[49426] = {index=6, val=2.75}   -- Emblems of Frost - Justice Points = (Emblems of Triumph + Emblems of Frost ) * 2.75
}
for key, value in pairs(EmblemsList) do
	local itemName, _, _, _, _, _, _, _, _, itemTexture = GetItemInfo(key)
	EmblemsList[key].itemName = itemName
	EmblemsList[key].itemTexture = itemTexture
end
-- Emblems and Badges ----------------------------------------------------------

-- Honor Points ----------------------------------------------------------------
local HonorCap = 4000
local HonorCapGold = 3500 -- 35 silver = 3500 copper
local HonorList = {
[43308] = {index=1, val=0.024}, -- Honor Points
[43307] = {index=2, val=0.85},  -- Arena Points

[20558] = {index=3, val=2.976}, -- Warsong Gulch Marks of Honor
[20559] = {index=4, val=2.976}, -- Arathi Basin Marks of Honor
[20560] = {index=5, val=2.976}, -- Alterac Valley Marks of Honor
[29024] = {index=6, val=2.976}, -- Eye of the Storm Marks of Honor
[42425] = {index=7, val=2.976}, -- Strand of the Ancients Marks of Honor
[47395] = {index=8, val=2.976}, -- Isle of Conquest Marks of Honor

[43589] = {index=9, val=19.08}, -- Wintergrasp Marks of Honor

[28558] = {index=10, val=1},    -- Spirit Shard
[37836] = {index=11, val=3},    -- Venture Coins
[43228] = {index=12, val=1.6}   -- Stone Keeper's Shards
}
for key, value in pairs(HonorList) do
	local itemName, _, _, _, _, _, _, _, _, itemTexture = GetItemInfo(key)
	HonorList[key].itemName = itemName
	if key == 43307 then
		HonorList[key].itemTexture = "Interface\\PVPFrame\\PVP-ArenaPoints-Icon"
	elseif key == 43308 then
		local factionGroup = UnitFactionGroup("player")
		if factionGroup then
			HonorList[key].itemTexture = "Interface\\PVPFrame\\PVP-Currency-"..factionGroup
		else
			HonorList[key].itemTexture = "Interface\\TargetingFrame\\UI-TargetingFrame-Skull"
		end
	else
		HonorList[key].itemTexture = itemTexture
	end
end
-- Honor Points ----------------------------------------------------------------
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
local function moneyFormat(money)
	local colorGold   = "ffd100"
	local colorSilver = "e6e6e6"
	local colorCopper = "c8602c"
	local gold = math_floor(money/10000)
	local silver = math_floor((money-gold*10000)/100)
	local copper = money-gold*10000-silver*100
	local m
	if money < 100 then
		m = "|cff"..colorCopper..copper..L["c"].."|r"
	end
	if money >= 100 and money < 10000 then
		if copper < 10 then copper = "0"..copper end
		m = "|cff"..colorSilver..silver..L["s"].."|r |cff"..colorCopper..copper..L["c"].."|r"
	end
	if money >= 10000 then
		if copper < 10 then copper = "0"..copper end
		if silver < 10 then silver = "0"..silver end
		m = "|cff"..colorGold..gold..L["g"].."|r |cff"..colorSilver..silver..L["s"].."|r |cff"..colorCopper..copper..L["c"].."|r"
	end
	return m
end
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
function CataCurrencyCalculator:InitOptions()
	SlashCmdList["CATACURRENCYCALCULATOR"] = function() CataCurrencyCalculator:MainFrameToggle() end
	SLASH_CATACURRENCYCALCULATOR1 = "/catacurrencycalculator"
	SLASH_CATACURRENCYCALCULATOR1 = "/ccc"

	if CataCurrencyCalculator_Options.version == nil then CataCurrencyCalculator_Options.version = 1 end
end
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
function CataCurrencyCalculator:LDBcheck()
	if LibStub and LibStub:GetLibrary("CallbackHandler-1.0", true) and LibStub:GetLibrary("LibDataBroker-1.1", true) then
		LibStub:GetLibrary("LibDataBroker-1.1"):NewDataObject("CataCurrencyCalculator", {
			type = "launcher",
			icon = addonicon,
			OnClick = function(self, button)
				CataCurrencyCalculator:MainFrameToggle()
			end,
		})
	end
end
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
function CataCurrencyCalculator:CreateInterfaceOptions()
	local options = CreateFrame("Frame", "CataCurrencyCalculator_InterfaceOptions")
	options.name = "CataCurrencyCalculator"

	local title = options:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	title:SetPoint("TOPLEFT", 16, -16)
	title:SetText("CataCurrencyCalculator")
	title:SetJustifyH("LEFT")
	title:SetJustifyV("TOP")

	CreateFrame("Button", "CataCurrencyCalculator_InterfaceOptions_GUI", CataCurrencyCalculator_InterfaceOptions, "UIPanelButtonTemplate")
	CataCurrencyCalculator_InterfaceOptions_GUI:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -10)
	CataCurrencyCalculator_InterfaceOptions_GUI:SetWidth(120)
	CataCurrencyCalculator_InterfaceOptions_GUI:SetHeight(24)
	CataCurrencyCalculator_InterfaceOptions_GUIText:SetText(L["Open GUI"])
	CataCurrencyCalculator_InterfaceOptions_GUI:SetScript("OnClick", function(self)
		InterfaceOptionsFrame_Show() -- hide InterfaceOptionsFrame
		HideUIPanel(GameMenuFrame) -- hide GameMenuFrame
		CataCurrencyCalculator:MainFrameToggle() -- show GUI
	end)

	CreateFrame("CheckButton", "CataCurrencyCalculator_InterfaceOptions_minimapButton", CataCurrencyCalculator_InterfaceOptions, "InterfaceOptionsCheckButtonTemplate")
	CataCurrencyCalculator_InterfaceOptions_minimapButton:SetPoint("TOPLEFT", CataCurrencyCalculator_InterfaceOptions_GUI, "BOTTOMLEFT", -4, -20)
	CataCurrencyCalculator_InterfaceOptions_minimapButtonText:SetText(L["Minimap-Button"])
	CataCurrencyCalculator_InterfaceOptions_minimapButton:SetChecked(CataCurrencyCalculator_Options.MinimapButton)
	CataCurrencyCalculator_InterfaceOptions_minimapButton.tooltipText = L["Shows a small movable Minimap Button."]
	CataCurrencyCalculator_InterfaceOptions_minimapButton:SetScript("OnClick", function(self)
		CataCurrencyCalculator_Options.MinimapButton = not CataCurrencyCalculator_Options.MinimapButton
		CataCurrencyCalculator:CreateMinimapButton()
	end)

	InterfaceOptions_AddCategory(options)
end
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
local function TemplateBorderTRBL(frame)
	local texture = frame:CreateTexture(nil, "BORDER")
	texture:SetPoint("TOPLEFT", 1, -1)
	texture:SetPoint("BOTTOMRIGHT", -1, 1)
	texture:SetTexture(0, 0, 0, 1)
	local textureBackground = frame:CreateTexture(nil, "BACKGROUND")
	textureBackground:SetPoint("TOPLEFT", 0, 0)
	textureBackground:SetPoint("BOTTOMRIGHT", 0, 0)
	textureBackground:SetTexture(0.4, 0.4, 0.4, 1)
end

local function TemplateTextButton(button, text, action)
	local name = button:GetName()

	local font
	local buttoncolor
	local fontcolor
	if action == 1 then
		font = "GameFontNormal"
		buttoncolor = {0.38, 0, 0, 1}
		fontcolor = {1, 0.82, 0, 1}
	elseif action == 2 then
		font = "GameFontWhiteSmall"
		buttoncolor = {0.38, 0, 0, 1}
		fontcolor = {1, 0.82, 0, 1}
	else
		font = "GameFontNormal"
		buttoncolor = {0, 0, 0, 1}
		fontcolor = {1, 0.82, 0, 1}
	end

	local textureBack = button:CreateTexture(nil, "BORDER")
	textureBack:SetPoint("TOPLEFT", 1, -1)
	textureBack:SetPoint("BOTTOMRIGHT", -1, 1)
	textureBack:SetTexture(0, 0, 0, 1)

	local texture = button:CreateTexture(nil, "ARTWORK")
	texture:SetPoint("TOPLEFT", 2, -2)
	texture:SetPoint("BOTTOMRIGHT", -2, 2)
	texture:SetTexture(buttoncolor[1], buttoncolor[2], buttoncolor[3], buttoncolor[4])

	local textureBorder = button:CreateTexture(nil, "BACKGROUND")
	textureBorder:SetPoint("TOPLEFT", 0, 0)
	textureBorder:SetPoint("BOTTOMRIGHT", 0, 0)
	textureBorder:SetTexture(0.4, 0.4, 0.4, 1)

	local textureHighlight = button:CreateTexture(nil, "OVERLAY")
	textureHighlight:SetPoint("TOPLEFT", 3, -3)
	textureHighlight:SetPoint("BOTTOMRIGHT", -3, 3)
	textureHighlight:SetTexture(0.6, 0.6, 0.6, 0.2)
	button:SetHighlightTexture(textureHighlight)

	local buttontext = button:CreateFontString(name.."Text", "OVERLAY", font)
	buttontext:SetText(text)
	--buttontext:SetWidth( buttontext:GetStringWidth()+10 )
	buttontext:SetHeight(12)
	buttontext:SetPoint("CENTER", button, "CENTER", 0, 0)
	buttontext:SetJustifyH("CENTER")
	buttontext:SetTextColor(fontcolor[1], fontcolor[2], fontcolor[3], fontcolor[4])

	button:SetScript("OnMouseDown", function() buttontext:SetPoint("CENTER", button, "CENTER", 1, -1) end)
	button:SetScript("OnMouseUp", function() buttontext:SetPoint("CENTER", button, "CENTER", 0, 0) end)
end

local function TemplateIconButton(button, cut)
	local name = button:GetName()

	local textureBack = button:CreateTexture(nil, "BORDER")
	textureBack:SetPoint("TOPLEFT", 1, -1)
	textureBack:SetPoint("BOTTOMRIGHT", -1, 1)
	textureBack:SetTexture(0, 0, 0, 1)

	local textureBorder = button:CreateTexture(nil, "BACKGROUND")
	textureBorder:SetPoint("TOPLEFT", 0, 0)
	textureBorder:SetPoint("BOTTOMRIGHT", 0, 0)
	textureBorder:SetTexture(0.4, 0.4, 0.4, 1)

	if cut == 1 then
		local textureNormal = button:CreateTexture(nil, "ARTWORK")
		textureNormal:SetPoint("TOPLEFT", 3, -3)
		textureNormal:SetPoint("BOTTOMRIGHT", -3, 3)
		textureNormal:SetTexture("Interface\\Buttons\\UI-Panel-MinimizeButton-Up")
		textureNormal:SetTexCoord(8/32, 22/32, 10/32, 22/32)
		button:SetNormalTexture(textureNormal)
		local texturePush = button:CreateTexture(nil, "ARTWORK")
		texturePush:SetPoint("TOPLEFT", 4, -4)
		texturePush:SetPoint("BOTTOMRIGHT", -4, 4)
		texturePush:SetTexture("Interface\\Buttons\\UI-Panel-MinimizeButton-Up")
		texturePush:SetTexCoord(8/32, 22/32, 10/32, 22/32)
		button:SetPushedTexture(texturePush)
	elseif cut == 2 then
		local textureNormal = button:CreateTexture(nil, "ARTWORK")
		textureNormal:SetPoint("TOPLEFT", 3, -3)
		textureNormal:SetPoint("BOTTOMRIGHT", -3, 3)
		textureNormal:SetTexture("Interface\\GossipFrame\\BinderGossipIcon")
		--textureNormal:SetTexCoord(8/32, 22/32, 10/32, 22/32)
		button:SetNormalTexture(textureNormal)
		local texturePush = button:CreateTexture(nil, "ARTWORK")
		texturePush:SetPoint("TOPLEFT", 4, -4)
		texturePush:SetPoint("BOTTOMRIGHT", -4, 4)
		texturePush:SetTexture("Interface\\GossipFrame\\BinderGossipIcon")
		--texturePush:SetTexCoord(8/32, 22/32, 10/32, 22/32)
		button:SetPushedTexture(texturePush)
	end

	local textureHighlight = button:CreateTexture(nil, "OVERLAY")
	textureHighlight:SetPoint("TOPLEFT", 3, -3)
	textureHighlight:SetPoint("BOTTOMRIGHT", -3, 3)
	textureHighlight:SetTexture(0.6, 0.6, 0.6, 0.2)
	button:SetHighlightTexture(textureHighlight)
end

local function TemplateDataList(button, itemName, itemTexture)
	local buttonName = button:GetName()

	local texture = button:CreateTexture(nil, "ARTWORK")
	texture:SetPoint("TOPLEFT", button, "TOPLEFT", 0, 0)
	texture:SetWidth(12)
	texture:SetHeight(12)
	texture:SetTexture(itemTexture)

	local name = button:CreateFontString(nil, "ARTWORK", "GameFontWhiteSmall")
	name:SetWidth(220)
	name:SetHeight(12)
	name:SetPoint("LEFT", button, "LEFT", 12+2, 0)
	name:SetJustifyH("LEFT")
	name:SetText(itemName)

	local count = button:CreateFontString(buttonName.."Count", "ARTWORK", "GameFontNormalSmall")
	count:SetWidth(70)
	count:SetHeight(12)
	count:SetPoint("LEFT", button, "LEFT", 12+2 + 220+2, 0)
	count:SetJustifyH("RIGHT")
	count:SetTextColor(1, 1, 0.5)

	local converted = button:CreateFontString(buttonName.."Converted", "ARTWORK", "GameFontWhiteSmall")
	converted:SetWidth(100)
	converted:SetHeight(12)
	converted:SetPoint("LEFT", button, "LEFT", 12+2 + 220+2 + 70+2, 0)
	converted:SetJustifyH("RIGHT")
	converted:SetTextColor(0.4, 0.6, 1)

	local textureHighlight = button:CreateTexture(nil, "ARTWORK")
	textureHighlight:SetPoint("TOPLEFT", button, "TOPLEFT", 0, 0)
	textureHighlight:SetPoint("BOTTOMRIGHT", button, "BOTTOMRIGHT", 0, 0)
	textureHighlight:SetTexture(1, 1, 1, 0.2)
	button:SetHighlightTexture(textureHighlight)
end
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
function CataCurrencyCalculator:CreateFrames()
	local framewidth = 418
	local frameheight = 485
	local mainframe = CreateFrame("Frame", "CataCurrencyCalculator_MainFrame", UIParent)
	TemplateBorderTRBL(mainframe)
	mainframe:EnableMouse(true)
	mainframe:SetMovable(true)
	mainframe:SetResizable(true)
	mainframe:SetToplevel(true)
	mainframe:SetClampedToScreen(true)
	mainframe:SetClampRectInsets(0, 0, 0, frameheight-28)
	mainframe:Hide()
	mainframe:SetWidth(framewidth)
	mainframe:SetHeight(frameheight)
	mainframe:SetScript("OnShow", function() CataCurrencyCalculator:MainFrameShow() end)
	mainframe:SetScript("OnHide", function() CataCurrencyCalculator:MainFrameHide() end)

	-- MoverInfoTop Frame START
	local moverinfo = CreateFrame("Frame", "CataCurrencyCalculator_MoverInfoTopFrame", mainframe)
	moverinfo:SetWidth(150)
	moverinfo:SetHeight(14)
	moverinfo:SetPoint("BOTTOM", CataCurrencyCalculator_MainFrame, "TOP", 0, 0)
	moverinfo:EnableMouse(true)
	moverinfo:Hide()
	local texture = moverinfo:CreateTexture(nil, "BACKGROUND")
	texture:SetAllPoints(moverinfo)
	texture:SetTexture(0, 0, 0, 0.5)
	local text = moverinfo:CreateFontString("CataCurrencyCalculator_MoverInfoTopFrame_Text", "ARTWORK", "GameFontWhiteSmall")
	text:SetPoint("CENTER", moverinfo, "CENTER", 0, 0)
	text:SetJustifyH("CENTER")
	text:SetTextColor(0.4, 0.4, 0.4, 1)
	-- MoverInfoTop Frame END

	-- Headline Frame START
	local headline = CreateFrame("Frame", "CataCurrencyCalculator_Headline", mainframe)
	TemplateBorderTRBL(headline)
	headline:SetWidth(framewidth)
	headline:SetHeight(28)
	headline:SetPoint("TOPLEFT", CataCurrencyCalculator_MainFrame, "TOPLEFT", 0, 0)
	headline:EnableMouse(true)

	local title = headline:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	title:SetPoint("LEFT", headline, "LEFT", 4, 0)
	title:SetJustifyH("LEFT")
	title:SetText("CataCurrencyCalculator")

	local headlineButtonX = CreateFrame("Button", "CataCurrencyCalculator_Headline_ButtonX", headline)
	TemplateIconButton(headlineButtonX, 1)
	headlineButtonX:SetWidth(20)
	headlineButtonX:SetHeight(20)
	headlineButtonX:SetPoint("RIGHT", CataCurrencyCalculator_Headline, "RIGHT", -4, 0)
	headlineButtonX:SetScript("OnClick", function() CataCurrencyCalculator:MainFrameToggle() end)

	local headlineButtonOptions = CreateFrame("Button", "CataCurrencyCalculator_Headline_ButtonOptions", headline)
	TemplateIconButton(headlineButtonOptions, 2)
	headlineButtonOptions:SetWidth(20)
	headlineButtonOptions:SetHeight(20)
	headlineButtonOptions:SetPoint("RIGHT", headlineButtonX, "LEFT", -4, 0)
	headlineButtonOptions:SetScript("OnClick", function() CataCurrencyCalculator:MainFrameToggle() InterfaceOptionsFrame_OpenToCategory("CataCurrencyCalculator") end)

	local headlineButtonMover = CreateFrame("Button", "CataCurrencyCalculator_Headline_ButtonMover", headline)
	headlineButtonMover:SetWidth(22)
	headlineButtonMover:SetHeight(28)
	headlineButtonMover:SetPoint("LEFT", headline, "LEFT", 0, 0)
	headlineButtonMover:SetPoint("RIGHT", headlineButtonOptions, "LEFT", 0, 0)
	local textureMover = headlineButtonMover:CreateTexture(nil, "BACKGROUND")
	textureMover:SetWidth(1)
	textureMover:SetHeight(1)
	textureMover:SetPoint("LEFT", title, "RIGHT", 0, 0)
	textureMover:SetPoint("TOPRIGHT", headlineButtonMover, "TOPRIGHT", 0, 0)
	textureMover:SetPoint("BOTTOMRIGHT", headlineButtonMover, "BOTTOMRIGHT", 0, 0)
	textureMover:SetTexture(1, 1, 1, 0)
	headlineButtonMover:SetScript("OnEnter", function() CataCurrencyCalculator:MoverInfo("MOVE", "TOP") end)
	headlineButtonMover:SetScript("OnLeave", function() CataCurrencyCalculator:MoverInfo() end)
	headlineButtonMover:SetScript("OnMouseDown", function() CataCurrencyCalculator_MainFrame:StartMoving() end)
	headlineButtonMover:SetScript("OnMouseUp", function() CataCurrencyCalculator_MainFrame:StopMovingOrSizing() CataCurrencyCalculator:SaveMainFramePos() end)
	-- Headline Frame END

	-- Options Frame START
	local options = CreateFrame("Frame", "CataCurrencyCalculator_OptionsFrame", mainframe)
	TemplateBorderTRBL(options)
	options:SetWidth(framewidth)
	options:SetHeight(36)
	options:SetPoint("TOPLEFT", CataCurrencyCalculator_Headline, "BOTTOMLEFT", 0, 1)
	options:EnableMouse(true)

	local updatedata = CreateFrame("Button", "CataCurrencyCalculator_OptionsFrame_UpdateData", options)
	TemplateTextButton(updatedata, L["Update"], 1)
	updatedata:SetWidth(150)
	updatedata:SetHeight(22)
	updatedata:SetPoint("CENTER", options, "CENTER", 0, 0)
	updatedata:SetScript("OnClick", function() CataCurrencyCalculator:CalculateCurrency() end)
	-- Options Frame END

	-- Data Frame START
	local function SortedPairs(t)
		local ntab = {}
		for k,v in pairs(t) do
			table.insert(ntab,k)
		end
		table.sort(ntab,
			function(a,b)
				if t[a].index < t[b].index then
					return true
				end
			end
		)
		local i = 0
		local function _f(_s,_v)
			i = i + 1
			local k = ntab[i]
			if (k) then
				return k,t[k]
			end
		end
		return _f,nil,nil
	end

	local data = CreateFrame("Frame", "CataCurrencyCalculator_DataFrame", mainframe)
	TemplateBorderTRBL(data)
	data:SetWidth(framewidth)
	data:SetHeight(frameheight - 28-36 +2)
	data:SetPoint("TOPLEFT", CataCurrencyCalculator_OptionsFrame, "BOTTOMLEFT", 0, 1)
	data:EnableMouse(true)

	-- - Emblems and Badges START
	local title = data:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	title:SetHeight(20)
	title:SetPoint("TOPLEFT", data, "TOPLEFT", 4, -8)
	title:SetJustifyH("CENTER")
	title:SetText(L["Emblems and Badges"])
	local now = data:CreateFontString(nil, "ARTWORK", "GameFontNormalSmall")
	now:SetHeight(20)
	now:SetWidth(70)
	now:SetPoint("LEFT", title, "LEFT", 12+2 + 220+2, 0)
	now:SetJustifyH("RIGHT")
	now:SetText(L["now"])
	now:SetTextColor(1, 1, 0.5)
	local cata = data:CreateFontString(nil, "ARTWORK", "GameFontNormalSmall")
	cata:SetHeight(20)
	cata:SetWidth(100)
	cata:SetPoint("LEFT", title, "LEFT", 12+2 + 220+2 + 70+2, 0)
	cata:SetJustifyH("RIGHT")
	cata:SetText(L["Cata"])
	cata:SetTextColor(0.4, 0.6, 1)

	local lButton
	for key, value in SortedPairs(EmblemsList) do
		local button = CreateFrame("Button", "CataCurrencyCalculator_DataFrame_Emblems_Button"..value.index, data)
		TemplateDataList(button, value.itemName, value.itemTexture)
		button:SetWidth(framewidth-8)
		button:SetHeight(14)
		if not lButton then
			button:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -4)
		else
			button:SetPoint("TOPLEFT", "CataCurrencyCalculator_DataFrame_Emblems_Button"..(value.index-1), "BOTTOMLEFT", 0, 0)
		end
		lButton = "CataCurrencyCalculator_DataFrame_Emblems_Button"..value.index
	end

	local button = CreateFrame("Button", nil, data)
	button:SetWidth(framewidth-8)
	button:SetHeight(14)
	button:SetPoint("TOPLEFT", lButton, "BOTTOMLEFT", 0, -4)
	local sumJP = button:CreateFontString(nil, "ARTWORK", "GameFontNormalSmall")
	sumJP:SetHeight(14)
	sumJP:SetPoint("TOPLEFT", button, "TOPLEFT", 0, 0)
	sumJP:SetJustifyH("LEFT")
	sumJP:SetText(L["Justice Points"])
	sumJP:SetTextColor(0.4, 0.6, 1)
	local sumJPvalue = button:CreateFontString("CataCurrencyCalculator_DataFrame_EmblemsSumJPValue", "ARTWORK", "GameFontNormalSmall")
	sumJPvalue:SetHeight(14)
	sumJPvalue:SetWidth(200)
	sumJPvalue:SetPoint("LEFT", sumJP, "LEFT", 12+2 + 220+2 + 70+2 - 100, 0)
	sumJPvalue:SetJustifyH("RIGHT")
	sumJPvalue:SetTextColor(0.4, 0.6, 1)
	local textureHighlight = button:CreateTexture(nil, "ARTWORK")
	textureHighlight:SetPoint("TOPLEFT", button, "TOPLEFT", 0, 0)
	textureHighlight:SetPoint("BOTTOMRIGHT", button, "BOTTOMRIGHT", 0, 0)
	textureHighlight:SetTexture(1, 1, 1, 0.2)
	button:SetHighlightTexture(textureHighlight)

	local button = CreateFrame("Button", nil, data)
	button:SetWidth(framewidth-8)
	button:SetHeight(14)
	button:SetPoint("TOPLEFT", sumJP, "BOTTOMLEFT", 0, -4)
	local sumGold = button:CreateFontString(nil, "ARTWORK", "GameFontNormalSmall")
	sumGold:SetHeight(14)
	sumGold:SetPoint("TOPLEFT", button, "TOPLEFT", 0, 0)
	sumGold:SetJustifyH("LEFT")
	sumGold:SetText(L["Gold"])
	sumGold:SetTextColor(0.4, 0.6, 1)
	local sumGoldvalue = button:CreateFontString("CataCurrencyCalculator_DataFrame_EmblemsSumGoldValue", "ARTWORK", "GameFontNormalSmall")
	sumGoldvalue:SetHeight(14)
	sumGoldvalue:SetWidth(200)
	sumGoldvalue:SetPoint("LEFT", sumGold, "LEFT", 12+2 + 220+2 + 70+2 - 100, 0)
	sumGoldvalue:SetJustifyH("RIGHT")
	sumGoldvalue:SetTextColor(0.4, 0.6, 1)
	local textureHighlight = button:CreateTexture(nil, "ARTWORK")
	textureHighlight:SetPoint("TOPLEFT", button, "TOPLEFT", 0, 0)
	textureHighlight:SetPoint("BOTTOMRIGHT", button, "BOTTOMRIGHT", 0, 0)
	textureHighlight:SetTexture(1, 1, 1, 0.2)
	button:SetHighlightTexture(textureHighlight)
	-- - Emblems and Badges END

	-- - Honor Points START
	local title = data:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	title:SetHeight(20)
	title:SetPoint("TOPLEFT", sumGold, "BOTTOMLEFT", 0, -8)
	title:SetJustifyH("CENTER")
	title:SetText(L["Honor Points"])
	local now = data:CreateFontString(nil, "ARTWORK", "GameFontNormalSmall")
	now:SetHeight(20)
	now:SetWidth(70)
	now:SetPoint("LEFT", title, "LEFT", 12+2 + 220+2, 0)
	now:SetJustifyH("RIGHT")
	now:SetText(L["now"])
	now:SetTextColor(1, 1, 0.5)
	local cata = data:CreateFontString(nil, "ARTWORK", "GameFontNormalSmall")
	cata:SetHeight(20)
	cata:SetWidth(100)
	cata:SetPoint("LEFT", title, "LEFT", 12+2 + 220+2 + 70+2, 0)
	cata:SetJustifyH("RIGHT")
	cata:SetText(L["Cata"])
	cata:SetTextColor(0.4, 0.6, 1)

	local lButton
	for key, value in SortedPairs(HonorList) do
		local button = CreateFrame("Button", "CataCurrencyCalculator_DataFrame_Honor_Button"..value.index, data)
		TemplateDataList(button, value.itemName, value.itemTexture)
		if key == 28558 then
			local editBox = CreateFrame("EditBox", "CataCurrencyCalculator_DataFrame_Honor_Button"..value.index.."EditBox", button, "InputBoxTemplate")
			editBox:SetWidth(45)
			editBox:SetHeight(14)
			editBox:SetPoint("LEFT", button, "LEFT", 220, 0)
			editBox:SetAutoFocus(false)
			editBox:SetMaxLetters(5)
			editBox:SetNumeric(true)
			editBox:SetScript("OnShow",         function(self) self:SetAutoFocus(false) end)
			editBox:SetScript("OnEnterPressed", function(self) self:ClearFocus() end)
			editBox:SetScript("OnTextChanged",  function(self)
				local value = self:GetNumber()
				if value == "" then value = 0 end
				value = tonumber(value)
				if value then
					HonorList[28558].count = value
					CataCurrencyCalculator:CalculateCurrency()
				end
			end)
		end
		button:SetWidth(framewidth-8)
		button:SetHeight(14)
		if not lButton then
			button:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -4)
		else
			button:SetPoint("TOPLEFT", "CataCurrencyCalculator_DataFrame_Honor_Button"..(value.index-1), "BOTTOMLEFT", 0, 0)
		end
		lButton = "CataCurrencyCalculator_DataFrame_Honor_Button"..value.index
	end

	local button = CreateFrame("Button", nil, data)
	button:SetWidth(framewidth-8)
	button:SetHeight(14)
	button:SetPoint("TOPLEFT", lButton, "BOTTOMLEFT", 0, -4)
	local sumHonor = button:CreateFontString(nil, "ARTWORK", "GameFontNormalSmall")
	sumHonor:SetHeight(14)
	sumHonor:SetPoint("TOPLEFT", button, "TOPLEFT", 0, 0)
	sumHonor:SetJustifyH("LEFT")
	sumHonor:SetText(L["New Honor Points"])
	sumHonor:SetTextColor(0.4, 0.6, 1)
	local sumHonorvalue = button:CreateFontString("CataCurrencyCalculator_DataFrame_HonorSumHonorValue", "ARTWORK", "GameFontNormalSmall")
	sumHonorvalue:SetHeight(14)
	sumHonorvalue:SetWidth(200)
	sumHonorvalue:SetPoint("LEFT", sumHonor, "LEFT", 12+2 + 220+2 + 70+2 - 100, 0)
	sumHonorvalue:SetJustifyH("RIGHT")
	sumHonorvalue:SetTextColor(0.4, 0.6, 1)
	local textureHighlight = button:CreateTexture(nil, "ARTWORK")
	textureHighlight:SetPoint("TOPLEFT", button, "TOPLEFT", 0, 0)
	textureHighlight:SetPoint("BOTTOMRIGHT", button, "BOTTOMRIGHT", 0, 0)
	textureHighlight:SetTexture(1, 1, 1, 0.2)
	button:SetHighlightTexture(textureHighlight)

	local button = CreateFrame("Button", nil, data)
	button:SetWidth(framewidth-8)
	button:SetHeight(14)
	button:SetPoint("TOPLEFT", sumHonor, "BOTTOMLEFT", 0, -4)
	local sumGold = button:CreateFontString(nil, "ARTWORK", "GameFontNormalSmall")
	sumGold:SetHeight(14)
	sumGold:SetPoint("TOPLEFT", button, "TOPLEFT", 0, 0)
	sumGold:SetJustifyH("LEFT")
	sumGold:SetText(L["Gold"])
	sumGold:SetTextColor(0.4, 0.6, 1)
	local sumGoldvalue = button:CreateFontString("CataCurrencyCalculator_DataFrame_HonorSumGoldValue", "ARTWORK", "GameFontNormalSmall")
	sumGoldvalue:SetHeight(14)
	sumGoldvalue:SetWidth(200)
	sumGoldvalue:SetPoint("LEFT", sumGold, "LEFT", 12+2 + 220+2 + 70+2 - 100, 0)
	sumGoldvalue:SetJustifyH("RIGHT")
	sumGoldvalue:SetTextColor(0.4, 0.6, 1)
	local textureHighlight = button:CreateTexture(nil, "ARTWORK")
	textureHighlight:SetPoint("TOPLEFT", button, "TOPLEFT", 0, 0)
	textureHighlight:SetPoint("BOTTOMRIGHT", button, "BOTTOMRIGHT", 0, 0)
	textureHighlight:SetTexture(1, 1, 1, 0.2)
	button:SetHighlightTexture(textureHighlight)
	-- - Honor Points END

	local button = CreateFrame("Button", nil, data)
	button:SetWidth(framewidth-8)
	button:SetHeight(14)
	button:SetPoint("TOPLEFT", sumGold, "BOTTOMLEFT", 0, -12)
	local sumGold = button:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	sumGold:SetHeight(14)
	sumGold:SetPoint("TOPLEFT", button, "TOPLEFT", 0, 0)
	sumGold:SetJustifyH("LEFT")
	sumGold:SetText(L["Total Gold"])
	sumGold:SetTextColor(0.4, 0.6, 1)
	local sumGoldvalue = button:CreateFontString("CataCurrencyCalculator_DataFrame_SumGoldValue", "ARTWORK", "GameFontNormal")
	sumGoldvalue:SetHeight(14)
	sumGoldvalue:SetWidth(200)
	sumGoldvalue:SetPoint("LEFT", sumGold, "LEFT", 12+2 + 220+2 + 70+2 - 100, 0)
	sumGoldvalue:SetJustifyH("RIGHT")
	sumGoldvalue:SetTextColor(0.4, 0.6, 1)
	local textureHighlight = button:CreateTexture(nil, "ARTWORK")
	textureHighlight:SetPoint("TOPLEFT", button, "TOPLEFT", 0, 0)
	textureHighlight:SetPoint("BOTTOMRIGHT", button, "BOTTOMRIGHT", 0, 0)
	textureHighlight:SetTexture(1, 1, 1, 0.2)
	button:SetHighlightTexture(textureHighlight)
	-- Data Frame END
end
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
function CataCurrencyCalculator:CreateMinimapButton()
	if not CataCurrencyCalculator_Options.MinimapButton then
		if CataCurrencyCalculator_MinimapButton then
			CataCurrencyCalculator_MinimapButton:Hide()
		end
		return
	else
		if CataCurrencyCalculator_MinimapButton then
			CataCurrencyCalculator_MinimapButton:Show()
			return
		end
	end

	if CataCurrencyCalculator_MinimapButton then return end

	local function MoveMinimapButton()
		local xpos
		local ypos
		local minimapShape = GetMinimapShape and GetMinimapShape() or "ROUND"
		if minimapShape == "SQUARE" then
			xpos = 110 * cos(CataCurrencyCalculator_Options.MinimapButtonPos or 0)
			ypos = 110 * sin(CataCurrencyCalculator_Options.MinimapButtonPos or 0)
			xpos = math.max(-82, math.min(xpos, 84))
			ypos = math.max(-86, math.min(ypos, 82))
		else
			xpos = 80 * cos(CataCurrencyCalculator_Options.MinimapButtonPos or 0)
			ypos = 80 * sin(CataCurrencyCalculator_Options.MinimapButtonPos or 0)
		end
		CataCurrencyCalculator_MinimapButton:SetPoint("TOPLEFT", Minimap, "TOPLEFT", 54-xpos, ypos-54)
	end

	local function DragMinimapButton()
		local xpos, ypos = GetCursorPosition()
		local xmin, ymin = Minimap:GetLeft() or 400, Minimap:GetBottom() or 400
		local scale = Minimap:GetEffectiveScale()
		xpos = xmin-xpos/scale+70
		ypos = ypos/scale-ymin-70
		CataCurrencyCalculator_Options.MinimapButtonPos = math.deg(math.atan2(ypos, xpos))
		MoveMinimapButton()
	end

	local MinimapButton = CreateFrame("Button", "CataCurrencyCalculator_MinimapButton", Minimap)
	MinimapButton:EnableMouse(true)
	MinimapButton:SetMovable(true)
	MinimapButton:SetToplevel(true)
	MinimapButton:SetWidth(32)
	MinimapButton:SetHeight(32)
	MinimapButton:SetPoint("TOPLEFT")
	MinimapButton:SetFrameStrata("LOW")
	MinimapButton:RegisterForClicks("AnyUp")
	MinimapButton:RegisterForDrag("LeftButton")

	local texture = MinimapButton:CreateTexture(nil, "ARTWORK")
	texture:SetWidth(54)
	texture:SetHeight(54)
	texture:SetPoint("TOPLEFT")
	texture:SetTexture("Interface\\Minimap\\MiniMap-TrackingBorder")

	local texture = MinimapButton:CreateTexture(nil, "BACKGROUND")
	texture:SetWidth(24)
	texture:SetHeight(24)
	texture:SetPoint("TOPLEFT", 2, -4)
	texture:SetTexture("Interface\\Minimap\\UI-Minimap-Background")

	local NormalTexture = MinimapButton:CreateTexture(nil, "ARTWORK")
	NormalTexture:SetWidth(12)
	NormalTexture:SetHeight(14)
	NormalTexture:SetPoint("TOPLEFT", 10, -8)
	NormalTexture:SetTexture(addonicon)
	MinimapButton:SetNormalTexture(NormalTexture)

	local PushedTexture = MinimapButton:CreateTexture(nil, "ARTWORK")
	PushedTexture:SetWidth(10)
	PushedTexture:SetHeight(12)
	PushedTexture:SetPoint("TOPLEFT", 11, -9)
	PushedTexture:SetTexture(addonicon)
	MinimapButton:SetPushedTexture(PushedTexture)

	local HighlightTexture = MinimapButton:CreateTexture(nil, "ARTWORK")
	HighlightTexture:SetPoint("TOPLEFT", 0, 0)
	HighlightTexture:SetPoint("BOTTOMRIGHT", 0, 0)
	HighlightTexture:SetTexture("Interface\\Minimap\\UI-Minimap-ZoomButton-Highlight")
	MinimapButton:SetHighlightTexture(HighlightTexture)

	MinimapButton:SetScript("OnEnter", function(self)
		GameTooltip:SetOwner(self, "ANCHOR_RIGHT")
		GameTooltip:AddLine("CataCurrencyCalculator", 1, 0.82, 0, 1)
		GameTooltip:Show()
	end)
	MinimapButton:SetScript("OnLeave", function(self) GameTooltip:Hide() end)
	MinimapButton:SetScript("OnClick", function(self, button) CataCurrencyCalculator:MainFrameToggle() end)
	MinimapButton:SetScript("OnDragStart", function(self) self:LockHighlight() self:SetScript("OnUpdate", DragMinimapButton) end)
	MinimapButton:SetScript("OnDragStop", function(self) self:SetScript("OnUpdate", nil) self:UnlockHighlight() end)

	MoveMinimapButton()
end
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
function CataCurrencyCalculator:MainFrameToggle()
	if CataCurrencyCalculator_MainFrame:IsShown() then
		CataCurrencyCalculator_MainFrame:Hide()
	else
		CataCurrencyCalculator_MainFrame:Show()
	end
end

function CataCurrencyCalculator:MainFramePos()
	if CataCurrencyCalculator_Options.MainFrame_relP then
		CataCurrencyCalculator_MainFrame:ClearAllPoints()
		CataCurrencyCalculator_MainFrame:SetPoint(CataCurrencyCalculator_Options.MainFrame_relP, CataCurrencyCalculator_Options.MainFrame_posX, CataCurrencyCalculator_Options.MainFrame_posY)
	else
		CataCurrencyCalculator_MainFrame:ClearAllPoints()
		CataCurrencyCalculator_MainFrame:SetPoint("CENTER", 0, 0)
	end
end

function CataCurrencyCalculator:MainFrameHide()
	PlaySound("igQuestListClose")
	CataCurrencyCalculator_InterfaceOptions_GUI:Enable()
end

function CataCurrencyCalculator:MainFrameShow()
	PlaySound("igQuestListOpen")
	CataCurrencyCalculator_InterfaceOptions_GUI:Disable()
	CataCurrencyCalculator:MainFramePos()
	CataCurrencyCalculator:CalculateCurrency()
end

function CataCurrencyCalculator:SaveMainFramePos()
	local point, relativeTo, relativePoint, x, y = CataCurrencyCalculator_MainFrame:GetPoint()
	CataCurrencyCalculator_Options.MainFrame_posX = x
	CataCurrencyCalculator_Options.MainFrame_posY = y
	CataCurrencyCalculator_Options.MainFrame_relP = relativePoint
end

function CataCurrencyCalculator:MoverInfo(action, where)
	if not action then
		CataCurrencyCalculator_MoverInfoTopFrame:Hide()
		return
	end

	if action == "MOVE" then
		CataCurrencyCalculator_MoverInfoTopFrame_Text:SetText(L["click & move"])
	end

	if where == "TOP" then
		CataCurrencyCalculator_MoverInfoTopFrame:Show()
	end
end
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
function CataCurrencyCalculator:CalculateCurrency()

	-- CurrencyList ----------------------------------------------------------------
	for i = 1, GetCurrencyListSize() do
		local name, isHeader, _, _, _, count, _, _, itemID = GetCurrencyListInfo(i)
		if name and name ~= "" and not isHeader and count then
			if EmblemsList[itemID] then
				EmblemsList[itemID].count = count
				--if itemID == 49426 then EmblemsList[itemID].count = 4000 end -- TEST
			end
			if HonorList[itemID] then
				HonorList[itemID].count = count
			end
		end
	end
	-- CurrencyList ----------------------------------------------------------------

	local totalGold = 0
	-- Emblems and Badges ----------------------------------------------------------
	local sumJP = 0
	local sumJPGold = 0
	local sumGold = 0
	for key, value in pairs(EmblemsList) do
		_G["CataCurrencyCalculator_DataFrame_Emblems_Button"..value.index.."Count"]:SetText(value.count or "-")
		if value.count and value.count > 0 then
			if key == 47241 or key == 49426 then -- JusticePoints
				sumJP = sumJP + value.count
			else
				sumGold = sumGold + (value.count*value.val*10000)
				_G["CataCurrencyCalculator_DataFrame_Emblems_Button"..value.index.."Converted"]:SetText( moneyFormat(math_floor((value.count*value.val*10000) * mult2 + 0.5) / mult2) )
			end
		else
			_G["CataCurrencyCalculator_DataFrame_Emblems_Button"..value.index.."Converted"]:SetText("-")
		end
	end

	sumJP = sumJP*EmblemsList[49426].val
	if sumJP > 4000 then
		sumJPGold = (sumJP-JusticeCap)*JusticeCapGold
		sumJP = 4000
	end
	sumGold = sumGold + sumJPGold

	if sumJP > 0 then
		if sumJP == 4000 then
			CataCurrencyCalculator_DataFrame_EmblemsSumJPValue:SetText( floor(sumJP) .." + ".. moneyFormat(floor(sumJPGold)) )
		else
			CataCurrencyCalculator_DataFrame_EmblemsSumJPValue:SetText(floor(sumJP))
		end
	else
		CataCurrencyCalculator_DataFrame_EmblemsSumJPValue:SetText("-")
	end

	if sumGold > 0 then
		CataCurrencyCalculator_DataFrame_EmblemsSumGoldValue:SetText( moneyFormat(floor(sumGold)) )
	else
		CataCurrencyCalculator_DataFrame_EmblemsSumGoldValue:SetText("-")
	end
	totalGold = totalGold + sumGold
	-- Emblems and Badges ----------------------------------------------------------

	-- Honor Points ----------------------------------------------------------------
	local sumHonor = 0
	local sumGold = 0
	for key, value in pairs(HonorList) do
		_G["CataCurrencyCalculator_DataFrame_Honor_Button"..value.index.."Count"]:SetText(value.count or "-")
		if value.count and value.count > 0 then
			sumHonor = sumHonor + (value.count*value.val)
			
			_G["CataCurrencyCalculator_DataFrame_Honor_Button"..value.index.."Converted"]:SetText(math_floor((value.count*value.val) * mult2 + 0.5) / mult2)
		else
			_G["CataCurrencyCalculator_DataFrame_Honor_Button"..value.index.."Converted"]:SetText("-")
		end
	end
	
	if sumHonor > HonorCap then
		sumGold = (sumHonor-HonorCap)*HonorCapGold
		sumHonor = HonorCap
	end
	if sumHonor > 0 then
		CataCurrencyCalculator_DataFrame_HonorSumHonorValue:SetText(floor(sumHonor))
	else
		CataCurrencyCalculator_DataFrame_HonorSumHonorValue:SetText("-")
	end

	if sumGold > 0 then
		CataCurrencyCalculator_DataFrame_HonorSumGoldValue:SetText( moneyFormat(floor(sumGold)) )
	else
		CataCurrencyCalculator_DataFrame_HonorSumGoldValue:SetText("-")
	end
	totalGold = totalGold + sumGold
	-- Honor Points ----------------------------------------------------------------

	if totalGold > 0 then
		CataCurrencyCalculator_DataFrame_SumGoldValue:SetText( moneyFormat(floor(totalGold)) )
	else
		CataCurrencyCalculator_DataFrame_SumGoldValue:SetText("-")
	end
end
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
local function OnEvent(self, event)
	if event == "PLAYER_LOGIN" then
		CataCurrencyCalculator:InitOptions()
		CataCurrencyCalculator:CreateInterfaceOptions()
		CataCurrencyCalculator:LDBcheck()
		CataCurrencyCalculator:CreateMinimapButton()
		CataCurrencyCalculator:CreateFrames()
		table.insert(UISpecialFrames, "CataCurrencyCalculator_MainFrame")
		CataCurrencyCalculator:UnregisterEvent("PLAYER_LOGIN")
	end
end
-- ---------------------------------------------------------------------------------------------------------------------

CataCurrencyCalculator:RegisterEvent("PLAYER_LOGIN")
CataCurrencyCalculator:SetScript("OnEvent", OnEvent)